##  Linking Beyond Suggested Fact Sheets
To link an item to a fact sheet other than the one suggested by the system, follow these steps:
  1. Choose a discovered item.
  2. Under Link Discovery Item to Your Fact Sheet(s) in the side panel, hover over a suggested fact sheet and choose Edit.
  3. Search for and select the desired fact sheet.
  4. Choose Link to establish the link.
